==> modelscope_studio-1.0.0b10.tar.gz: modelscope_studio-1.0.0b10/backend/modelscope_studio/components/antd/color_picker/preset/__init__.py <==
from __future__ import annotations

from .....utils.dev import ModelScopeLayoutComponent, resolve_frontend_dir


class AntdColorPickerPreset(ModelScopeLayoutComponent):
    """
    """
    EVENTS = []

    # supported slots
    SLOTS = [
        'label',
    ]

    def __init__(
            self,
            props: dict | None = None,
            *,
            label: str | None = None,
            colors: list[str] = None,
            default_open: bool = None,
            as_item: str | None = None,
            _internal: None = None,
            # gradio properties
            visible: bool = True,
            elem_id: str | None = None,
            elem_classes: list[str] | str | None = None,
            elem_style: dict | None = None,
            render: bool = True,
            **kwargs):
        super().__init__(visible=visible,
                         elem_id=elem_id,
                         elem_classes=elem_classes,
                         render=render,
                         as_item=as_item,
                         elem_style=elem_style,
                         **kwargs)
        self.props = props
        self.label = label
        self.colors = colors
        self.default_open = default_open

    FRONTEND_DIR = resolve_frontend_dir("color-picker", 'preset')

    @property
    def skip_api(self):
        return True

    def preprocess(self, payload: None) -> None:
        return payload

    def postprocess(self, value: None) -> None:

        return value

    def example_payload(self) -> None:
        return None

    def example_value(self) -> None:
        return None

==> modelscope_studio-1.3.0.tar.gz: modelscope_studio-1.3.0/backend/modelscope_studio/components/antd/color_picker/preset/__init__.py <==
from __future__ import annotations

from .....utils.dev import ModelScopeLayoutComponent, resolve_frontend_dir


class AntdColorPickerPreset(ModelScopeLayoutComponent):
    """
    """
    EVENTS = []

    # supported slots
    SLOTS = [
        'label',
    ]

    def __init__(
            self,
            props: dict | None = None,
            *,
            label: str | None = None,
            colors: list[str] | None = None,
            default_open: bool | None = None,
            key: str | None = None,
            as_item: str | None = None,
            _internal: None = None,
            # gradio properties
            visible: bool = True,
            elem_id: str | None = None,
            elem_classes: list[str] | str | None = None,
            elem_style: dict | None = None,
            render: bool = True,
            **kwargs):
        super().__init__(visible=visible,
                         elem_id=elem_id,
                         elem_classes=elem_classes,
                         render=render,
                         as_item=as_item,
                         elem_style=elem_style,
                         **kwargs)
        self.props = props
        self.label = label
        self.key = key
        self.colors = colors
        self.default_open = default_open

    FRONTEND_DIR = resolve_frontend_dir("color-picker", 'preset')

    @property
    def skip_api(self):
        return True

    def preprocess(self, payload: None) -> None:
        return payload

    def postprocess(self, value: None) -> None:

        return value

    def example_payload(self) -> None:
        return None

    def example_value(self) -> None:
        return None
